.. _whatsnew_0233:

What's new in 0.23.3 (July 7, 2018)
-----------------------------------

{{ header }}

This release fixes a build issue with the sdist for Python 3.7 (:issue:`21785`)
There are no other changes.

.. _whatsnew_0.23.3.contributors:

Contributors
~~~~~~~~~~~~

.. contributors:: v0.23.2..v0.23.3
